# Copyright (C) 2020 by ÿnérant, eichhornchen, nicomarg, charlse
# SPDX-License-Identifier: GPL-3.0-or-later

from squirrelbattle.interfaces import Map
from .display import Display
from ..game import Game


class MapDisplay(Display):
    """
    A class to handle the display of the map.
    """

    map: Map

    def __init__(self, *args):
        super().__init__(*args)

    def update(self, game: Game) -> None:
        self.map = game.map
        self.pad = self.newpad(self.map.height,
                               self.pack.tile_width * self.map.width + 1)

    def update_pad(self) -> None:
        for j in range(len(self.map.tiles)):
            for i in range(len(self.map.tiles[j])):
                if not self.map.seen_tiles[j][i]:
                    continue
                fg, bg = self.map.tiles[j][i].visible_color(self.pack) if \
                    self.map.visibility[j][i] else \
                    self.map.tiles[j][i].hidden_color(self.pack)
                self.addstr(self.pad, j, self.pack.tile_width * i,
                            self.map.tiles[j][i].char(self.pack), fg, bg)
        for e in self.map.entities:
            if self.map.visibility[e.y][e.x]:
                self.addstr(self.pad, e.y, self.pack.tile_width * e.x,
                            self.pack[e.name.upper()],
                            self.pack.entity_fg_color,
                            self.pack.entity_bg_color)

        # Display Path map for debug purposes
        # from squirrelbattle.entities.player import Player
        # players = [ p for p in self.map.entities if isinstance(p,Player) ]
        # player = players[0] if len(players) > 0 else None
        # if player:
        #     for x in range(self.map.width):
        #         for y in range(self.map.height):
        #             if (y,x) in player.paths:
        #                 deltay, deltax = (y - player.paths[(y, x)][0],
        #                     x - player.paths[(y, x)][1])
        #                 if (deltay, deltax) == (-1, 0):
        #                     character = '↓'
        #                 elif (deltay, deltax) == (1, 0):
        #                     character = '↑'
        #                 elif (deltay, deltax) == (0, -1):
        #                     character = '→'
        #                 else:
        #                     character = '←'
        #                 self.addstr(self.pad, y, self.pack.tile_width * x,
        #                     character, self.pack.tile_fg_color,
        #                     self.pack.tile_bg_color)

    def display(self) -> None:
        y, x = self.map.currenty, self.pack.tile_width * self.map.currentx
        deltay, deltax = (self.height // 2) + 1, (self.width // 2) + 1
        pminrow, pmincol = y - deltay, x - deltax
        sminrow, smincol = max(-pminrow, 0), max(-pmincol, 0)
        deltay, deltax = self.height - deltay, self.width - deltax
        smaxrow = self.map.height - (y + deltay) + self.height - 1
        smaxrow = min(smaxrow, self.height - 1)
        smaxcol = self.pack.tile_width * self.map.width - \
            (x + deltax) + self.width - 1

        # Wrap perfectly the map according to the width of the tiles
        pmincol = self.pack.tile_width * (pmincol // self.pack.tile_width)
        smincol = self.pack.tile_width * (smincol // self.pack.tile_width)
        smaxcol = self.pack.tile_width \
            * (smaxcol // self.pack.tile_width + 1) - 1

        smaxcol = min(smaxcol, self.width - 1)
        pminrow = max(0, min(self.map.height, pminrow))
        pmincol = max(0, min(self.pack.tile_width * self.map.width, pmincol))

        self.pad.erase()
        self.update_pad()
        self.refresh_pad(self.pad, pminrow, pmincol, sminrow, smincol, smaxrow,
                         smaxcol)
